@@ -281,7 +281,8 @@ inversePValueZTest <- function(estimates, SE, gamma){
 
 informWeight_adapted <- function(mu, mu_0 , q, trWeights.rowsums){
   greaterZero <- as.integer(mu > mu_0) * as.integer(q > 0) 
-  return((1 - (1-q^{mu-mu_0}) * trWeights.rowsums) * greaterZero)
+  return((1 - trWeights.rowsums +  q^{mu-mu_0}*trWeights.rowsums) * greaterZero)
+  #return equals return((1 - (1-q^{mu-mu_0}) * trWeights.rowsums) * greaterZero)
 }
 
 ###############################################################################
@@ -335,17 +336,15 @@ funcBisec <- function(f_1, f_2, a, b, maxIter = 1000, tol = 1/10^3){
   f <- function(x){f_1(x)-f_2(x)}
   f.a <- f(a)
   f.b <- f(b)
-  if(f.a > 0 || f.b < 0 ){ 
+  if(f.a > 0){ 
     stop("Bisection cannot be executed! The function value f_1(a) must be less
-         than or equal to f_2(a) and f_1(b) must be greater than or equal
-         to f_2(b)!") 
+         than or equal to f_2(a)!") 
   }
-  if(f.a == 0){
-    return(a)
+  if(f.b < 0 ){ 
+    stop("Bisection cannot be executed! The function value f_1(b) must be
+    greater than or equal to f_2(b)!") 
   }
-  
-  check <- f_2(b) # for numerical stability 
-  if(f.b == 0 && check != 0){
+  if(f.b == 0){
     return(b)
   }
   
@@ -355,17 +354,8 @@ funcBisec <- function(f_1, f_2, a, b, maxIter = 1000, tol = 1/10^3){
     }
     xmid <- (a + b)/2
     ymid <- f(xmid)
-    if (ymid < 0) { # ymid < 0 means f_1(x_mid) < f_2(xmid)
+    if (ymid <= 0) { # ymid < 0 means f_1(x_mid) <= f_2(xmid)
       a <- xmid
-    }
-    else if(ymid == 0){ # i.e. f_1(x_mid) == f_2(x)
-      check <-  f_2(xmid) 
-      if(check != 0){ # for numerical stability
-        a <- xmid
-        break  
-      }else{
-        b <- xmid
-      }
     }else{ # i.e. f_1(x_mid) > f_2(x)
       b <- xmid
     }
@@ -422,7 +412,7 @@ weightsGTP <- function(mu, g, weights, alpha, q, mu_0){
     return(weights * alpha) 
     
   }else if(numOfPosMu == 1){
-    i.p <- indices.pos[1] # single index for which mu[i]>mu_0[i] is true
+    i.p <- indices.pos[1] # single index for which mu[i] > mu_0[i] is true
     eta.mu <- numeric(m)
     alpha_posInd <- weights[i.p] * alpha 
     eta.mu[i.p] <- alpha_posInd * q.eqZeroIndicator[i.p] 
@@ -466,14 +456,20 @@ weightsGTP <- function(mu, g, weights, alpha, q, mu_0){
         
         for(j in (l+1):numOfPosMu){ # only the transition weights between 
           # non-rejected hypotheses need to be updated 
+          
+          # for scaling of update rule of transition weights:
+          informWeightAdp <- informWeight_adapted(mu, mu_0 , q, rowSums(g))
+          scaleFactorP1 <- sum(g.mu[j,(l+1):m])+(sum(g.mu[l,(l+1):m])-g.mu[l,j])*g.mu[j,l]
+          scaleFactorP2 <- sum(g.mu[j,(m+1):(m+j)]*informWeightAdp[indices.pos[1:j]])+ sum(g.mu[l,(m+1):(m+j)]*informWeightAdp[indices.pos[1:j]])*g.mu[j,l]
+          scaleFactor <- scaleFactorP1 + scaleFactorP2
+          
           for(k in (l+1):(m+j)){ # for m+j+1 <= k <= m+numOfPosMu the
             # transition weights remain 0. Thus no update is necessary
             
-            if(g.mu[j,l] * g.mu[l,j] == 1 || j == k){
+            if(j == k){
               g.mu[j,k] <- 0
             }else{
-              g.mu[j,k] <- (g.mu[j,k] + g.mu[j,l] * g.mu[l,k])/
-                (1 - g.mu[j,l] * g.mu[l,j])
+              g.mu[j,k] <- (g.mu[j,k] + g.mu[j,l] * g.mu[l,k])/max(scaleFactor,10^{-300})
             } 
           }
         }
@@ -484,7 +480,7 @@ weightsGTP <- function(mu, g, weights, alpha, q, mu_0){
     eta.mu <-eta.mu[order(c(indices.nonpos,indices.pos))] # rearrange the 
     # entries of the vector into the original arrangement
     
-    #eta.mu gives alpha^{mu}/q^{max(0,mu-mu_0)} or
+    # reta.mu gives alpha^{mu}/q^{max(0,mu-mu_0)} or
     # alpha^{mu}/informWeight_adapted(mu, mu_0 , q, rowSums(g)) where alpha^{mu}
     # is defined as in the underlying paper. If q[i] == 0 and mu[i]< mu_0[i] it
     # holds eta.mu[i] = alpha_i^{mu}. If q[i] == 0 and mu[i]>=mu_0[i] it holds 
